<?php
namespace OrganizationsManagement\Controller;
use Exception;
use OrganizationsManagement\Traits\TQuery;
use OrganizationsManagement\Traits\TResponse;
use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Service\OqueHaDeNovo as OqueHaDeNovoService;

class OqueHaDeNovo extends Simple {

    use TResponse;

    /**
     * @var OqueHaDeNovoService
     */
    private $oqueHaDeNovoService;

    /**
     * CadastroAssuntoProduto constructor.
     * @param OqueHaDeNovoService $oqueHaDeNovoService
     */
    public function __construct(OqueHaDeNovoService $oqueHaDeNovoService)
    {
        $this->oqueHaDeNovoService = $oqueHaDeNovoService;
    }

    /**
     * @param DTO\Request $request
     * @param DTO\Response $response
     * @throws Exception
     */
    public function findItemProduct(DTO\Request $request, DTO\Response $response){
        try{
            $data = $this->oqueHaDeNovoService->findItemProduct($request->getParameters());
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findOmProduct(DTO\Request $request, DTO\Response $response){
        try{
            $data = $this->oqueHaDeNovoService->findOmProduct();
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTreeGridItem(DTO\Request $request, DTO\Response $response){
        try{
            $data = $this->oqueHaDeNovoService->findTreeGridItem($request->getParameters());
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveModalAddOqueHaDeNovo(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            if(!empty($data['DOCUMENT'])){
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($data, 'DOCUMENT', 'OM/OqueHaDeNovo');
            }
            $dsassunto = $data["DSASSUNTO"];
            $assuntos = sizeof($data["ASSUNTO"]) > 0 ? $data["ASSUNTO"] : null;
            $produtoId = $data["PRODUTO_ID"];
            $paiId = $data["ITEM_SUPERIOR"];
            $document = empty($data['DOCUMENT']) ? array() : $data['DOCUMENT'];
            $this->oqueHaDeNovoService->saveModalAddOqueHaDeNovo($dsassunto, $assuntos, $produtoId, $paiId, $document);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function uploadDocumentOQA(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            if(!empty($data['DOCUMENT'])){
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($data, 'DOCUMENT', 'OM/OqueHaDeNovo');
            }
            $document = empty($data['DOCUMENT']) ? array() : $data['DOCUMENT'];
            $pathFile = null;
            if (!empty($document)) {
                $pathFile = $document[0]['path'];
            }
            $this->sendResponse($document, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPdfFrame(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $request->getParameters();
            $this->oqueHaDeNovoService->downloadFile($data);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSubjectsItem(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            $id = $data['ID'];
            $data = $this->oqueHaDeNovoService->getSubjectsItem($id);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPathFileItem(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            $id = $data['ID'];
            $data = $this->oqueHaDeNovoService->getPathFileItem($id);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateItemOqueHaDeNovo(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            $this->oqueHaDeNovoService->updateItemOqueHaDeNovo($data);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function removeItem(DTO\Request $request, DTO\Response $response)
    {
        try {
            $datas = $request->getParameters();
            foreach ($datas["data"] as $data) {
                $id = $data["ID"];
                $this->oqueHaDeNovoService->removeItem($id);
            }
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

}
