<?php
namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Repository\OqueHaDeNovo as OqueHaDeNovoRepository;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Remote\HttpInterface;

class OqueHaDeNovo {
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var OqueHaDeNovoRepository
     */
    private $oqueHaDeNovoRepository;

    private $fileServerFilesUrl;

    /**
     * Classification constructor.
     * @param EntityManager $entityManager
     * @param CadastroAssuntoRepository $cadastroAssuntoRepository
     */
    public function __construct(EntityManager $entityManager, OqueHaDeNovoRepository $oqueHaDeNovoRepository, $fileServerFilesUrl)
    {
        $this->entityManager = $entityManager;
        $this->oqueHaDeNovoRepository = $oqueHaDeNovoRepository;
        $this->fileServerFilesUrl = $fileServerFilesUrl;
    }

    public function findItemProduct($parametros)
    {
        $fetchOnDemand = '';
        if (isset($parametros["PARENT"]) && ($parametros["PARENT"]) != 'NULL' ) {
            $fetchOnDemand = " AND PARENT = '" . $parametros["PARENT"] . "'";
        }

        $fetchOnDemandPrimeiraLinha = '';
        if (isset($parametros["PARENT"]) && $parametros["PARENT"] == 'NULL') {
            $fetchOnDemandPrimeiraLinha = " AND PARENT IS NULL";
        }

        return $this->oqueHaDeNovoRepository->findItemProduct($fetchOnDemand, $fetchOnDemandPrimeiraLinha);
    }

    public function findOmProduct()
    {
        return $this->oqueHaDeNovoRepository->findOmProduct();
    }

    public function findTreeGridItem($parametros)
    {
        $produtoId = null;
        if (sizeof($parametros) > 0) {
            $produtoId = $parametros["PRODUTO_ID"];
        }

        $fetchOnDemand = '';
        if ($produtoId != 'NULL' ) {
            $fetchOnDemand = " AND PRODUTO_ID = '" . $produtoId . "'";
        }

        $fetchOnDemandPrimeiraLinha = '';
        if ($produtoId == 'NULL') {
            $fetchOnDemandPrimeiraLinha = " AND PRODUTO_ID IS NULL";
        }
        return $this->oqueHaDeNovoRepository->findTreeGridItem($fetchOnDemand, $fetchOnDemandPrimeiraLinha);
    }

    public function saveModalAddOqueHaDeNovo($dsassunto, $assuntos, $produtoId, $paiId, $document) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            $typeFile = null;
            $labelFile = null;
            $sizeFile = null;
            $pathFile = null;
            if (!empty($document)) {
                $typeFile = $document[0]['type'];
                $labelFile = $document[0]['name'];
                $sizeFile = $document[0]['size'];
                $pathFile = $document[0]['path'];
            }
            $omOQAItem = InstanceProvider::getFactory()->getCadItem()->createItem($dsassunto, $produtoId, $paiId, $pathFile, $typeFile, $sizeFile , $labelFile);
            $this->entityManager->persist($omOQAItem);
            $this->entityManager->flush();
            $omOQAItemRepository = InstanceProvider::getRepository()->getOmOqaItem()->findOneBy(array('produtoId' => $produtoId));
            if ($assuntos !== null) {
                foreach ($assuntos as $assunto) {
                    $omOQAItemAssunto = InstanceProvider::getFactory()->getCadItem()->createItemAssunto($omOQAItemRepository->getId(), $assunto["ID"]);
                    $this->entityManager->persist($omOQAItemAssunto);
                    $this->entityManager->flush();
                }
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function getPathOqueHaDeNovo($pdfPath)
    {   
        if ($pdfPath == null) {
            return $data[] = array();    
        }
        return $data[] = array(
            'pdfPath' => $this->fileServerFilesUrl . $pdfPath,
        );
    }

    public function getSubjectsItem($id)
    {   
        $omOQAItemAssuntos = InstanceProvider::getRepository()->getOmOqaItemAssunto()->findBy(array('itemId' => $id));
        $arrayAssuntoId = array();
        foreach ($omOQAItemAssuntos as $omOQAItemAssunto) {
            array_push($arrayAssuntoId, $omOQAItemAssunto->getAssuntoId());
        }
        return $arrayAssuntoId;
    }

    public function getPathFileItem($id)
    {   
        $omOQAItemRepository = InstanceProvider::getRepository()->getOmOqaItem()->findOneBy(array('id' => $id));
        return $this->getPathOqueHaDeNovo($omOQAItemRepository->getFilename());
    }

    public function updateItemOqueHaDeNovo($data) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            $id = $data['ID'];
            $dsassunto = $data['DSASSUNTO'];
            $assuntos = sizeof($data["ASSUNTO"]) > 0 ? $data["ASSUNTO"] : null;
            $omOQAItemAssuntoRepository = InstanceProvider::getRepository()->getOmOqaItemAssunto()->findBy(array('itemId' => $id));
            if ($assuntos !== null) {
                foreach ($assuntos as $assunto) {
                    if (!$omOQAItemAssuntoRepository) {
                        $omOQAItemAssunto = InstanceProvider::getFactory()->getCadItem()->createItemAssunto($id, $assunto["ID"]);
                        $this->entityManager->persist($omOQAItemAssunto);
                        $this->entityManager->flush();
                    } else {
                        foreach ($omOQAItemAssuntoRepository as $idItemAssunto) {
                            $this->entityManager->remove($idItemAssunto);
                            $this->entityManager->flush();
                        }
                        $omOQAItemAssunto = InstanceProvider::getFactory()->getCadItem()->createItemAssunto($id, $assunto["ID"]);
                        $this->entityManager->persist($omOQAItemAssunto);
                        $this->entityManager->flush();
                    }
                }
            } else {
                if ($omOQAItemAssuntoRepository) {
                    foreach ($omOQAItemAssuntoRepository as $idItemAssunto) {
                        $this->entityManager->remove($idItemAssunto);
                        $this->entityManager->flush();
                    }
                }
            }
            $omOQAItemRepository = InstanceProvider::getRepository()->getOmOqaItem()->findOneBy(array('id' => $id));
            if (empty($data['DOCUMENT']) && $omOQAItemRepository->getFilename() == null) {
                $omOQAItem = InstanceProvider::getFactory()->getCadItem()->updateItem(
                $omOQAItemRepository, $id, $dsassunto, $omOQAItemRepository->getProdutoId(), $omOQAItemRepository->getPaiId(),
                $omOQAItemRepository->getFilename(), $omOQAItemRepository->getFiletype(), $omOQAItemRepository->getFilesize(),
                $omOQAItemRepository->getFilelabel());
                $this->entityManager->persist($omOQAItem);
                $this->entityManager->flush();
            }

            if (!empty($data['DOCUMENT']) && $omOQAItemRepository->getFilename() !== null) {
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($data, 'DOCUMENT', 'OM/OqueHaDeNovo');
                $typeFile = $data['DOCUMENT'][0]['type'];
                $labelFile = $data['DOCUMENT'][0]['name'];
                $sizeFile = $data['DOCUMENT'][0]['size'];
                $pathFile = $data['DOCUMENT'][0]['path'];
                $omOQAItem = InstanceProvider::getFactory()->getCadItem()->updateItem(
                $omOQAItemRepository, $id, $dsassunto, $omOQAItemRepository->getProdutoId(), $omOQAItemRepository->getPaiId(),
                $pathFile, $typeFile, $sizeFile, $labelFile);
                $this->entityManager->persist($omOQAItem);
                $this->entityManager->flush();
            }

            if (!empty($data['DOCUMENT']) && $omOQAItemRepository->getFilename() === null) {
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($data, 'DOCUMENT', 'OM/OqueHaDeNovo');
                $typeFile = $data['DOCUMENT'][0]['type'];
                $labelFile = $data['DOCUMENT'][0]['name'];
                $sizeFile = $data['DOCUMENT'][0]['size'];
                $pathFile = $data['DOCUMENT'][0]['path'];
                $omOQAItem = InstanceProvider::getFactory()->getCadItem()->updateItem(
                $omOQAItemRepository, $id, $dsassunto, $omOQAItemRepository->getProdutoId(), $omOQAItemRepository->getPaiId(),
                $pathFile, $typeFile, $sizeFile, $labelFile);
                $this->entityManager->persist($omOQAItem);
                $this->entityManager->flush();
            }

            if (empty($data['DOCUMENT']) && $omOQAItemRepository->getFilename() !== null) {
                $omOQAItem = InstanceProvider::getFactory()->getCadItem()->updateItem(
                $omOQAItemRepository, $id, $dsassunto, $omOQAItemRepository->getProdutoId(), $omOQAItemRepository->getPaiId(),
                null, null, null, null);
                $this->entityManager->persist($omOQAItem);
                $this->entityManager->flush();
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeItem($id)
    {   
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            $idsAssunto = InstanceProvider::getRepository()->getOmOqaItemAssunto()->findBy(array('itemId' => $id));
            if (!empty($idsAssunto)) {
                foreach ($idsAssunto as $omOQAItemAssuntoRepository) {
                    $this->entityManager->remove($omOQAItemAssuntoRepository);
                    $this->entityManager->flush();
                }
            }
            $this->removeFilhoItemRecursivo($id);
            $omOQAItemRepository = InstanceProvider::getRepository()->getOmOqaItem()->findOneBy(array('id' => $id));
            $this->entityManager->remove($omOQAItemRepository);
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeFilhoItemRecursivo($id) {
        $omOQAItemRepository = InstanceProvider::getRepository()->getOmOqaItem()->findBy(array('paiId' => $id));
        foreach ($omOQAItemRepository as $filho) {
            $this->removeFilhoItemRecursivo($filho->getId());
            $this->entityManager->remove($filho);
        }
    }

    public function downloadFile($params) {
        $filePath = $params['path'];
        $fileName = $params['name'];
        $fileType = $params['type'];
        $fileLink = $this->fileServerFilesUrl . $params['path'];
        $this->setParamsForDownload($fileType, null, $fileName, $fileLink, false);
        InstanceProvider::getFileUploaderServe()->deleteFile($filePath);
        exit;
    }

    public function setParamsForDownload($type, $size, $name, $fileName,$isAttachment = true)
    {
        header('Accept-Ranges: none');
        header("Content-Type: " . $type);
        if($size){
            header("Content-Length: " . $size);
        }

        if($isAttachment){
            header('Content-Disposition: attachment; filename="' . $name.'"');
        }else{
            header('Content-Disposition: inline;filename="' . $name.'"');
        }
        readfile($fileName);
    }
}
